# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.custom_payload_field import CustomPayloadField
from instana_client.models.mobile_app_alert_rule import MobileAppAlertRule
from instana_client.models.mobile_app_time_threshold import MobileAppTimeThreshold
from instana_client.models.rule_with_threshold_mobile_app_alert_rule import RuleWithThresholdMobileAppAlertRule
from instana_client.models.tag_filter_expression import TagFilterExpression
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from instana_client.models.threshold import Threshold
from typing import Optional, Set
from typing_extensions import Self

class MobileAppAlertConfig(BaseModel):
    """
    MobileAppAlertConfig
    """ # noqa: E501
    alert_channel_ids: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=1024)]] = Field(default=None, description="List of IDs of alert channels defined in Instana. Can be left empty.", alias="alertChannelIds")
    alert_channels: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Set of alert channel IDs associated with the severity.", alias="alertChannels")
    complete_tag_filter_expression: Optional[TagFilterExpression] = Field(default=None, alias="completeTagFilterExpression")
    custom_payload_fields: Annotated[List[CustomPayloadField], Field(min_length=0, max_length=20)] = Field(description="Custom payload fields to send additional information in the alert notifications. Can be left empty.", alias="customPayloadFields")
    description: Annotated[str, Field(min_length=0, strict=True, max_length=65536)] = Field(description="Description of the mobile app alert configuration. Used as a template for the description of alert/event notifications triggered by this Smart Alert configuration.")
    grace_period: Optional[StrictInt] = Field(default=None, description="The duration for which an alert remains open after conditions are no longer violated, with the alert auto-closing once the grace period expires.", alias="gracePeriod")
    granularity: StrictInt = Field(description="The evaluation granularity used for detection of violations of the defined threshold. Defines the size of the tumbling window used.")
    mobile_app_id: Annotated[str, Field(min_length=0, strict=True, max_length=64)] = Field(description="ID of the mobile app that this Smart Alert configuration is applied to.", alias="mobileAppId")
    name: Annotated[str, Field(min_length=0, strict=True, max_length=256)] = Field(description="Name of the mobile app alert configuration. Used as a template for the title of alert/event notifications triggered by this Smart Alert configuration.")
    rule: Optional[MobileAppAlertRule] = None
    rules: Optional[Annotated[List[RuleWithThresholdMobileAppAlertRule], Field(min_length=1, max_length=1)]] = Field(default=None, description="A list of rules where each rule is associated with multiple thresholds and their corresponding severity levels. This enables more complex alert configurations with validations to ensure consistent and logical threshold-severity combinations.")
    severity: Optional[Annotated[int, Field(le=10, strict=True, ge=5)]] = Field(default=None, description="The severity of the alert when triggered, which is either 5 (Warning), or 10 (Critical).")
    tag_filter_expression: TagFilterExpressionElement = Field(alias="tagFilterExpression")
    threshold: Optional[Threshold] = None
    time_threshold: MobileAppTimeThreshold = Field(alias="timeThreshold")
    triggering: Optional[StrictBool] = Field(default=None, description="Optional flag to indicate whether an Incident is also triggered or not.")
    __properties: ClassVar[List[str]] = ["alertChannelIds", "alertChannels", "completeTagFilterExpression", "customPayloadFields", "description", "gracePeriod", "granularity", "mobileAppId", "name", "rule", "rules", "severity", "tagFilterExpression", "threshold", "timeThreshold", "triggering"]

    @field_validator('granularity')
    def granularity_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set([60000, 300000, 600000, 900000, 1200000, 1800000]):
            raise ValueError("must be one of enum values (60000, 300000, 600000, 900000, 1200000, 1800000)")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MobileAppAlertConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of complete_tag_filter_expression
        if self.complete_tag_filter_expression:
            _dict['completeTagFilterExpression'] = self.complete_tag_filter_expression.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_payload_fields (list)
        _items = []
        if self.custom_payload_fields:
            for _item_custom_payload_fields in self.custom_payload_fields:
                if _item_custom_payload_fields:
                    _items.append(_item_custom_payload_fields.to_dict())
            _dict['customPayloadFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of rule
        if self.rule:
            _dict['rule'] = self.rule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in rules (list)
        _items = []
        if self.rules:
            for _item_rules in self.rules:
                if _item_rules:
                    _items.append(_item_rules.to_dict())
            _dict['rules'] = _items
        # override the default output from pydantic by calling `to_dict()` of tag_filter_expression
        if self.tag_filter_expression:
            _dict['tagFilterExpression'] = self.tag_filter_expression.to_dict()
        # override the default output from pydantic by calling `to_dict()` of threshold
        if self.threshold:
            _dict['threshold'] = self.threshold.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_threshold
        if self.time_threshold:
            _dict['timeThreshold'] = self.time_threshold.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MobileAppAlertConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alertChannelIds": obj.get("alertChannelIds"),
            "alertChannels": obj.get("alertChannels"),
            "completeTagFilterExpression": TagFilterExpression.from_dict(obj["completeTagFilterExpression"]) if obj.get("completeTagFilterExpression") is not None else None,
            "customPayloadFields": [CustomPayloadField.from_dict(_item) for _item in obj["customPayloadFields"]] if obj.get("customPayloadFields") is not None else None,
            "description": obj.get("description"),
            "gracePeriod": obj.get("gracePeriod"),
            "granularity": obj.get("granularity") if obj.get("granularity") is not None else 600000,
            "mobileAppId": obj.get("mobileAppId"),
            "name": obj.get("name"),
            "rule": MobileAppAlertRule.from_dict(obj["rule"]) if obj.get("rule") is not None else None,
            "rules": [RuleWithThresholdMobileAppAlertRule.from_dict(_item) for _item in obj["rules"]] if obj.get("rules") is not None else None,
            "severity": obj.get("severity"),
            "tagFilterExpression": TagFilterExpressionElement.from_dict(obj["tagFilterExpression"]) if obj.get("tagFilterExpression") is not None else None,
            "threshold": Threshold.from_dict(obj["threshold"]) if obj.get("threshold") is not None else None,
            "timeThreshold": MobileAppTimeThreshold.from_dict(obj["timeThreshold"]) if obj.get("timeThreshold") is not None else None,
            "triggering": obj.get("triggering")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.access_rule import AccessRule
from instana_client.models.match_expression_dto import MatchExpressionDTO
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from typing import Optional, Set
from typing_extensions import Self

class NewApplicationConfig(BaseModel):
    """
    NewApplicationConfig
    """ # noqa: E501
    access_rules: Annotated[List[AccessRule], Field(min_length=1, max_length=64)] = Field(description="Defines permissions and access relationships. ", alias="accessRules")
    boundary_scope: StrictStr = Field(description="**INBOUND**: Inbound calls are calls initiated from outside the application and where the destination service is part of the selected application perspective.  **ALL**: Results and metrics for not only calls at the application perspective boundary, but also those occurring within the application perspective.  **DEFAULT**: Default value, for Application Perspectives created before the introduction of `ALL` and `INBOUND`. At present, whenever new Application Perspectives are created, there are only 2 options to select: `ALL` or `INBOUND`. It is recommended to use either `ALL` or `INBOUND` as `DEFAULT` is deprecated. `DEFAULT` is treated as `INBOUND`. ", alias="boundaryScope")
    label: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="Name of the Application Perspective. Eg: `app1`.")
    match_specification: Optional[MatchExpressionDTO] = Field(default=None, alias="matchSpecification")
    scope: StrictStr = Field(description="**INCLUDE_NO_DOWNSTREAM** : Only the selected services from the filters are included (call this the core set). This is useful when you treat the services as opaque. An example would be the services that represent 3rd party APIs.  **INCLUDE_IMMEDIATE_DOWNSTREAM_DATABASE_AND_MESSAGING** : Include the core set of services from the filters and then expand this core set to include the database and messaging services that the core set directly interacts with. This is useful if you are want to monitor a set of services and their direct dependencies. For example, a development team responsible for several micro-services.  **INCLUDE_ALL_DOWNSTREAM** : It effortlessly and automatically includes all the services that form the entire end-to-end dependency chain of the core set of services. This is useful if the AP will be used for troubleshooting. ")
    tag_filter_expression: Optional[TagFilterExpressionElement] = Field(default=None, alias="tagFilterExpression")
    __properties: ClassVar[List[str]] = ["accessRules", "boundaryScope", "label", "matchSpecification", "scope", "tagFilterExpression"]

    @field_validator('boundary_scope')
    def boundary_scope_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ALL', 'INBOUND', 'DEFAULT']):
            raise ValueError("must be one of enum values ('ALL', 'INBOUND', 'DEFAULT')")
        return value

    @field_validator('scope')
    def scope_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['INCLUDE_NO_DOWNSTREAM', 'INCLUDE_IMMEDIATE_DOWNSTREAM_DATABASE_AND_MESSAGING', 'INCLUDE_ALL_DOWNSTREAM']):
            raise ValueError("must be one of enum values ('INCLUDE_NO_DOWNSTREAM', 'INCLUDE_IMMEDIATE_DOWNSTREAM_DATABASE_AND_MESSAGING', 'INCLUDE_ALL_DOWNSTREAM')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NewApplicationConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in access_rules (list)
        _items = []
        if self.access_rules:
            for _item_access_rules in self.access_rules:
                if _item_access_rules:
                    _items.append(_item_access_rules.to_dict())
            _dict['accessRules'] = _items
        # override the default output from pydantic by calling `to_dict()` of match_specification
        if self.match_specification:
            _dict['matchSpecification'] = self.match_specification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tag_filter_expression
        if self.tag_filter_expression:
            _dict['tagFilterExpression'] = self.tag_filter_expression.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NewApplicationConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessRules": [AccessRule.from_dict(_item) for _item in obj["accessRules"]] if obj.get("accessRules") is not None else None,
            "boundaryScope": obj.get("boundaryScope"),
            "label": obj.get("label"),
            "matchSpecification": MatchExpressionDTO.from_dict(obj["matchSpecification"]) if obj.get("matchSpecification") is not None else None,
            "scope": obj.get("scope"),
            "tagFilterExpression": TagFilterExpressionElement.from_dict(obj["tagFilterExpression"]) if obj.get("tagFilterExpression") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from instana_client.models.get_test_result import GetTestResult
from instana_client.models.get_test_result_analytic import GetTestResultAnalytic
from instana_client.models.get_test_result_base import GetTestResultBase
from instana_client.models.get_test_result_list import GetTestResultList
from instana_client.models.get_test_summary_result import GetTestSummaryResult
from instana_client.models.test_result import TestResult
from instana_client.models.test_result_detail_data import TestResultDetailData
from instana_client.models.test_result_list_result import TestResultListResult
from instana_client.models.test_result_metadata import TestResultMetadata

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class SyntheticTestPlaybackResultsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_location_summary_list(
        self,
        get_test_result_base: Optional[GetTestResultBase] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultListResult:
        """Get a list of Synthetic locations with last run test on each location data

        Get summary information for Synthetic locations matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_base:
        :type get_test_result_base: GetTestResultBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_location_summary_list_serialize(
            get_test_result_base=get_test_result_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_location_summary_list_with_http_info(
        self,
        get_test_result_base: Optional[GetTestResultBase] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultListResult]:
        """Get a list of Synthetic locations with last run test on each location data

        Get summary information for Synthetic locations matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_base:
        :type get_test_result_base: GetTestResultBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_location_summary_list_serialize(
            get_test_result_base=get_test_result_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_location_summary_list_without_preload_content(
        self,
        get_test_result_base: Optional[GetTestResultBase] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a list of Synthetic locations with last run test on each location data

        Get summary information for Synthetic locations matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_base:
        :type get_test_result_base: GetTestResultBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_location_summary_list_serialize(
            get_test_result_base=get_test_result_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_location_summary_list_serialize(
        self,
        get_test_result_base,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_test_result_base is not None:
            _body_params = get_test_result_base


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/synthetics/results/locationsummarylist',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result(
        self,
        get_test_result: Optional[GetTestResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResult:
        """Get Synthetic test playback results

        Get a list of aggregated playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result:
        :type get_test_result: GetTestResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_serialize(
            get_test_result=get_test_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_with_http_info(
        self,
        get_test_result: Optional[GetTestResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResult]:
        """Get Synthetic test playback results

        Get a list of aggregated playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result:
        :type get_test_result: GetTestResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_serialize(
            get_test_result=get_test_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_without_preload_content(
        self,
        get_test_result: Optional[GetTestResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Synthetic test playback results

        Get a list of aggregated playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result:
        :type get_test_result: GetTestResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_serialize(
            get_test_result=get_test_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_serialize(
        self,
        get_test_result,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_test_result is not None:
            _body_params = get_test_result


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/synthetics/results',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result_analytic(
        self,
        get_test_result_analytic: Optional[GetTestResultAnalytic] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultListResult:
        """Get a list of Synthetic tests based on the specified analytic function

        Get a list of playback results metrics for Synthetic tests matching the specified parameters for the specified analytic For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_analytic:
        :type get_test_result_analytic: GetTestResultAnalytic
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_analytic_serialize(
            get_test_result_analytic=get_test_result_analytic,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_analytic_with_http_info(
        self,
        get_test_result_analytic: Optional[GetTestResultAnalytic] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultListResult]:
        """Get a list of Synthetic tests based on the specified analytic function

        Get a list of playback results metrics for Synthetic tests matching the specified parameters for the specified analytic For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_analytic:
        :type get_test_result_analytic: GetTestResultAnalytic
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_analytic_serialize(
            get_test_result_analytic=get_test_result_analytic,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_analytic_without_preload_content(
        self,
        get_test_result_analytic: Optional[GetTestResultAnalytic] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a list of Synthetic tests based on the specified analytic function

        Get a list of playback results metrics for Synthetic tests matching the specified parameters for the specified analytic For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_analytic:
        :type get_test_result_analytic: GetTestResultAnalytic
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_analytic_serialize(
            get_test_result_analytic=get_test_result_analytic,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_analytic_serialize(
        self,
        get_test_result_analytic,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_test_result_analytic is not None:
            _body_params = get_test_result_analytic


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/synthetics/results/analytic',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result_detail_data(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file contents to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file contents")],
        name: Annotated[Optional[StrictStr], Field(description="Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS")] = None,
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file contents")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultDetailData:
        """Get Synthetic test playback result detail data

        Download the contents of the Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file contents to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file contents (required)
        :type type: str
        :param name: Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS
        :type name: str
        :param start_time: Start time of the test result detailed file contents
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            name=name,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultDetailData",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_detail_data_with_http_info(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file contents to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file contents")],
        name: Annotated[Optional[StrictStr], Field(description="Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS")] = None,
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file contents")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultDetailData]:
        """Get Synthetic test playback result detail data

        Download the contents of the Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file contents to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file contents (required)
        :type type: str
        :param name: Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS
        :type name: str
        :param start_time: Start time of the test result detailed file contents
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            name=name,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultDetailData",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_detail_data_without_preload_content(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file contents to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file contents")],
        name: Annotated[Optional[StrictStr], Field(description="Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS")] = None,
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file contents")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Synthetic test playback result detail data

        Download the contents of the Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file contents to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file contents (required)
        :type type: str
        :param name: Name of the test result detailed file, if more than one file available for the same type. Can be used when parameter type=LOGS
        :type name: str
        :param start_time: Start time of the test result detailed file contents
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            name=name,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultDetailData",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_detail_data_serialize(
        self,
        testid,
        testresultid,
        type,
        name,
        start_time,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if testid is not None:
            _path_params['testid'] = testid
        if testresultid is not None:
            _path_params['testresultid'] = testresultid
        # process the query parameters
        if type is not None:
            
            _query_params.append(('type', type))
            
        if name is not None:
            
            _query_params.append(('name', name))
            
        if start_time is not None:
            
            _query_params.append(('startTime', start_time))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/synthetics/results/{testid}/{testresultid}/detail',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result_detail_data_file(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Download the synthetic test playback result detail data file

        Download a Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file (required)
        :type type: str
        :param start_time: Start time of the test result detailed file
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_file_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_detail_data_file_with_http_info(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Download the synthetic test playback result detail data file

        Download a Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file (required)
        :type type: str
        :param start_time: Start time of the test result detailed file
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_file_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_detail_data_file_without_preload_content(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed file to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the  test result detailed file to be retrieved")],
        type: Annotated[StrictStr, Field(description="Type of the test result detailed file")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed file")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Download the synthetic test playback result detail data file

        Download a Synthetic the playback result detail data file matching the specified file type For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed file to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the  test result detailed file to be retrieved (required)
        :type testresultid: str
        :param type: Type of the test result detailed file (required)
        :type type: str
        :param start_time: Start time of the test result detailed file
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_detail_data_file_serialize(
            testid=testid,
            testresultid=testresultid,
            type=type,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_detail_data_file_serialize(
        self,
        testid,
        testresultid,
        type,
        start_time,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if testid is not None:
            _path_params['testid'] = testid
        if testresultid is not None:
            _path_params['testresultid'] = testresultid
        # process the query parameters
        if type is not None:
            
            _query_params.append(('type', type))
            
        if start_time is not None:
            
            _query_params.append(('startTime', start_time))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/octet-stream'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/synthetics/results/{testid}/{testresultid}/file',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result_list(
        self,
        get_test_result_list: Optional[GetTestResultList] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultListResult:
        """Get a list of Synthetic test playback results

        Get a list of playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_list:
        :type get_test_result_list: GetTestResultList
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_list_serialize(
            get_test_result_list=get_test_result_list,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_list_with_http_info(
        self,
        get_test_result_list: Optional[GetTestResultList] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultListResult]:
        """Get a list of Synthetic test playback results

        Get a list of playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_list:
        :type get_test_result_list: GetTestResultList
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_list_serialize(
            get_test_result_list=get_test_result_list,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_list_without_preload_content(
        self,
        get_test_result_list: Optional[GetTestResultList] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a list of Synthetic test playback results

        Get a list of playback results metrics for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_result_list:
        :type get_test_result_list: GetTestResultList
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_list_serialize(
            get_test_result_list=get_test_result_list,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_list_serialize(
        self,
        get_test_result_list,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_test_result_list is not None:
            _body_params = get_test_result_list


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/synthetics/results/list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_synthetic_result_metadata(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed description to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the test result detailed description to be retrieved")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed description")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultMetadata:
        """Get Synthetic test playback detail result description(metadata)

        Gets the list of detailed data file names associated to a Synthetic playback result For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed description to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the test result detailed description to be retrieved (required)
        :type testresultid: str
        :param start_time: Start time of the test result detailed description
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_metadata_serialize(
            testid=testid,
            testresultid=testresultid,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultMetadata",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_synthetic_result_metadata_with_http_info(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed description to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the test result detailed description to be retrieved")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed description")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultMetadata]:
        """Get Synthetic test playback detail result description(metadata)

        Gets the list of detailed data file names associated to a Synthetic playback result For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed description to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the test result detailed description to be retrieved (required)
        :type testresultid: str
        :param start_time: Start time of the test result detailed description
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_metadata_serialize(
            testid=testid,
            testresultid=testresultid,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultMetadata",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_synthetic_result_metadata_without_preload_content(
        self,
        testid: Annotated[StrictStr, Field(description="Test id of the test result detailed description to be retrieved")],
        testresultid: Annotated[StrictStr, Field(description="Test result id of the test result detailed description to be retrieved")],
        start_time: Annotated[Optional[StrictInt], Field(description="Start time of the test result detailed description")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Synthetic test playback detail result description(metadata)

        Gets the list of detailed data file names associated to a Synthetic playback result For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param testid: Test id of the test result detailed description to be retrieved (required)
        :type testid: str
        :param testresultid: Test result id of the test result detailed description to be retrieved (required)
        :type testresultid: str
        :param start_time: Start time of the test result detailed description
        :type start_time: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_synthetic_result_metadata_serialize(
            testid=testid,
            testresultid=testresultid,
            start_time=start_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultMetadata",
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_synthetic_result_metadata_serialize(
        self,
        testid,
        testresultid,
        start_time,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if testid is not None:
            _path_params['testid'] = testid
        if testresultid is not None:
            _path_params['testresultid'] = testresultid
        # process the query parameters
        if start_time is not None:
            
            _query_params.append(('startTime', start_time))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/synthetics/results/{testid}/{testresultid}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_test_summary_list(
        self,
        get_test_summary_result: Optional[GetTestSummaryResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TestResultListResult:
        """Get a list of Synthetic tests with success rate and average response time data

        Get a summary of the playback results metrics and success rate for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_summary_result:
        :type get_test_summary_result: GetTestSummaryResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_test_summary_list_serialize(
            get_test_summary_result=get_test_summary_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_test_summary_list_with_http_info(
        self,
        get_test_summary_result: Optional[GetTestSummaryResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TestResultListResult]:
        """Get a list of Synthetic tests with success rate and average response time data

        Get a summary of the playback results metrics and success rate for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_summary_result:
        :type get_test_summary_result: GetTestSummaryResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_test_summary_list_serialize(
            get_test_summary_result=get_test_summary_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_test_summary_list_without_preload_content(
        self,
        get_test_summary_result: Optional[GetTestSummaryResult] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a list of Synthetic tests with success rate and average response time data

        Get a summary of the playback results metrics and success rate for Synthetic tests matching the specified parameters For more information on Synthetic Test Playback Results please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Synthetic+Monitoring#synthetic-test-playback-results.

        :param get_test_summary_result:
        :type get_test_summary_result: GetTestSummaryResult
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_test_summary_list_serialize(
            get_test_summary_result=get_test_summary_result,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TestResultListResult",
            '401': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_test_summary_list_serialize(
        self,
        get_test_summary_result,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_test_summary_result is not None:
            _body_params = get_test_summary_result


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/synthetics/results/testsummarylist',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class SliReport(BaseModel):
    """
    SliReport
    """ # noqa: E501
    error_budget_remaining: Optional[StrictInt] = Field(default=None, description="This is the error budget remaining compared to the total error budget", alias="errorBudgetRemaining")
    from_timestamp: Optional[StrictInt] = Field(default=None, description="from timestamp in milliseconds (13-digit)", alias="fromTimestamp")
    sli: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Service Level Indicator: This indicates the actual performance measure of the service")
    slo: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Service Level Objective: This is the target value that should be met by the SLI")
    to_timestamp: Optional[StrictInt] = Field(default=None, description="to timestamp in milliseconds (13-digit)", alias="toTimestamp")
    total_error_budget: Optional[StrictInt] = Field(default=None, description="This is the total error budget available", alias="totalErrorBudget")
    violation_distribution: Optional[Dict[str, StrictInt]] = Field(default=None, alias="violationDistribution")
    __properties: ClassVar[List[str]] = ["errorBudgetRemaining", "fromTimestamp", "sli", "slo", "toTimestamp", "totalErrorBudget", "violationDistribution"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SliReport from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SliReport from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "errorBudgetRemaining": obj.get("errorBudgetRemaining"),
            "fromTimestamp": obj.get("fromTimestamp"),
            "sli": obj.get("sli"),
            "slo": obj.get("slo"),
            "toTimestamp": obj.get("toTimestamp"),
            "totalErrorBudget": obj.get("totalErrorBudget"),
            "violationDistribution": obj.get("violationDistribution")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.sli_settings_api import SLISettingsApi


class TestSLISettingsApi(unittest.TestCase):
    """SLISettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SLISettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_sli_config(self) -> None:
        """Test case for create_sli_config

        Create SLI Config
        """
        pass

    def test_create_sli_config_v2(self) -> None:
        """Test case for create_sli_config_v2

        Create SLI Config
        """
        pass

    def test_delete_sli_config(self) -> None:
        """Test case for delete_sli_config

        Delete SLI Config
        """
        pass

    def test_delete_sli_config_v2(self) -> None:
        """Test case for delete_sli_config_v2

        Delete SLI Config
        """
        pass

    def test_get_all_sli_configs(self) -> None:
        """Test case for get_all_sli_configs

        Get All SLI Configs
        """
        pass

    def test_get_all_sli_configs_v2(self) -> None:
        """Test case for get_all_sli_configs_v2

        Get All SLI Configs
        """
        pass

    def test_get_sli_config(self) -> None:
        """Test case for get_sli_config

        Get SLI Config
        """
        pass

    def test_get_sli_config_v2(self) -> None:
        """Test case for get_sli_config_v2

        Get SLI Config
        """
        pass

    def test_get_sli_configs_for_entity_type_and_id_v2(self) -> None:
        """Test case for get_sli_configs_for_entity_type_and_id_v2

        Get all SLI configs for entity type and entity id
        """
        pass

    def test_update_sli_config(self) -> None:
        """Test case for update_sli_config

        Update SLI Config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_result_detail_data import TestResultDetailData

class TestTestResultDetailData(unittest.TestCase):
    """TestResultDetailData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResultDetailData:
        """Test TestResultDetailData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResultDetailData`
        """
        model = TestResultDetailData()
        if include_optional:
            return TestResultDetailData(
                har = {
                    'key' : None
                    },
                image_files = {
                    'key' : [
                        'YQ=='
                        ]
                    },
                log_files = {
                    'key' : ''
                    },
                logs = '',
                subtransaction_avg_metrics = {
                    'key' : None
                    },
                subtransactions = [
                    instana_client.models.test_result_subtransaction.TestResultSubtransaction(
                        metrics = {
                            'key' : None
                            }, 
                        properties = {
                            'key' : None
                            }, )
                    ],
                test_id = '',
                test_result_id = '',
                videos = [
                    'YQ=='
                    ]
            )
        else:
            return TestResultDetailData(
        )
        """

    def testTestResultDetailData(self):
        """Test TestResultDetailData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace_activity_tree_node_details import TraceActivityTreeNodeDetails

class TestTraceActivityTreeNodeDetails(unittest.TestCase):
    """TraceActivityTreeNodeDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TraceActivityTreeNodeDetails:
        """Test TraceActivityTreeNodeDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceActivityTreeNodeDetails`
        """
        model = TraceActivityTreeNodeDetails()
        if include_optional:
            return TraceActivityTreeNodeDetails(
                batch_self_time = 56,
                batch_size = 0,
                destination = instana_client.models.span_relation.SpanRelation(
                    applications = [
                        instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', )
                        ], 
                    endpoint = instana_client.models.endpoint.Endpoint(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        is_synthetic = True, 
                        label = '', 
                        service_id = '', 
                        synthetic = True, 
                        synthetic_type = 'NON_SYNTHETIC', 
                        technologies = [
                            ''
                            ], 
                        type = 'UNDEFINED', ), 
                    physical_context = instana_client.models.physical_context.PhysicalContext(
                        cloudfoundry = instana_client.models.cloudfoundry_physical_context.CloudfoundryPhysicalContext(
                            application = instana_client.models.snapshot_preview.SnapshotPreview(
                                data = {
                                    'key' : None
                                    }, 
                                id = '', 
                                label = '', 
                                plugin = '', 
                                time = 1, ), 
                            cf_instance_index = '', 
                            organization = instana_client.models.snapshot_preview.SnapshotPreview(
                                id = '', 
                                label = '', 
                                plugin = '', 
                                time = 1, ), 
                            space = , ), 
                        cluster = , 
                        container = , 
                        host = , 
                        kubernetes = instana_client.models.kubernetes_physical_context.KubernetesPhysicalContext(
                            namespace = , 
                            node = , 
                            pod = , ), 
                        process = , ), 
                    service = instana_client.models.service.Service(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], ), ),
                duration = 0,
                error_count = 0,
                id = '',
                is_synthetic = True,
                label = '',
                logs = [
                    instana_client.models.span_excerpt.SpanExcerpt(
                        data = {
                            'key' : None
                            }, 
                        database_integrations = [
                            instana_client.models.database_integration.DatabaseIntegration(
                                type = '', 
                                url = '', )
                            ], 
                        duration = 0, 
                        error_count = 0, 
                        foreign_parent_id = '', 
                        id = '', 
                        kind = 'UNKNOWN', 
                        name = '', 
                        parent_id = '', 
                        stack_trace = [
                            instana_client.models.stack_trace_item.StackTraceItem(
                                file = '', 
                                line = '', 
                                method = '', )
                            ], 
                        start = 1, )
                    ],
                min_self_time = 56,
                network_time = 56,
                source = instana_client.models.span_relation.SpanRelation(
                    applications = [
                        instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', )
                        ], 
                    endpoint = instana_client.models.endpoint.Endpoint(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        is_synthetic = True, 
                        label = '', 
                        service_id = '', 
                        synthetic = True, 
                        synthetic_type = 'NON_SYNTHETIC', 
                        technologies = [
                            ''
                            ], 
                        type = 'UNDEFINED', ), 
                    physical_context = instana_client.models.physical_context.PhysicalContext(
                        cloudfoundry = instana_client.models.cloudfoundry_physical_context.CloudfoundryPhysicalContext(
                            application = instana_client.models.snapshot_preview.SnapshotPreview(
                                data = {
                                    'key' : None
                                    }, 
                                id = '', 
                                label = '', 
                                plugin = '', 
                                time = 1, ), 
                            cf_instance_index = '', 
                            organization = instana_client.models.snapshot_preview.SnapshotPreview(
                                id = '', 
                                label = '', 
                                plugin = '', 
                                time = 1, ), 
                            space = , ), 
                        cluster = , 
                        container = , 
                        host = , 
                        kubernetes = instana_client.models.kubernetes_physical_context.KubernetesPhysicalContext(
                            namespace = , 
                            node = , 
                            pod = , ), 
                        process = , ), 
                    service = instana_client.models.service.Service(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], ), ),
                spans = [
                    instana_client.models.span_excerpt.SpanExcerpt(
                        data = {
                            'key' : None
                            }, 
                        database_integrations = [
                            instana_client.models.database_integration.DatabaseIntegration(
                                type = '', 
                                url = '', )
                            ], 
                        duration = 0, 
                        error_count = 0, 
                        foreign_parent_id = '', 
                        id = '', 
                        kind = 'UNKNOWN', 
                        name = '', 
                        parent_id = '', 
                        stack_trace = [
                            instana_client.models.stack_trace_item.StackTraceItem(
                                file = '', 
                                line = '', 
                                method = '', )
                            ], 
                        start = 1, )
                    ],
                start = 1,
                synthetic = True
            )
        else:
            return TraceActivityTreeNodeDetails(
                id = '',
                label = '',
                logs = [
                    instana_client.models.span_excerpt.SpanExcerpt(
                        data = {
                            'key' : None
                            }, 
                        database_integrations = [
                            instana_client.models.database_integration.DatabaseIntegration(
                                type = '', 
                                url = '', )
                            ], 
                        duration = 0, 
                        error_count = 0, 
                        foreign_parent_id = '', 
                        id = '', 
                        kind = 'UNKNOWN', 
                        name = '', 
                        parent_id = '', 
                        stack_trace = [
                            instana_client.models.stack_trace_item.StackTraceItem(
                                file = '', 
                                line = '', 
                                method = '', )
                            ], 
                        start = 1, )
                    ],
                spans = [
                    instana_client.models.span_excerpt.SpanExcerpt(
                        data = {
                            'key' : None
                            }, 
                        database_integrations = [
                            instana_client.models.database_integration.DatabaseIntegration(
                                type = '', 
                                url = '', )
                            ], 
                        duration = 0, 
                        error_count = 0, 
                        foreign_parent_id = '', 
                        id = '', 
                        kind = 'UNKNOWN', 
                        name = '', 
                        parent_id = '', 
                        stack_trace = [
                            instana_client.models.stack_trace_item.StackTraceItem(
                                file = '', 
                                line = '', 
                                method = '', )
                            ], 
                        start = 1, )
                    ],
        )
        """

    def testTraceActivityTreeNodeDetails(self):
        """Test TraceActivityTreeNodeDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.meta_data import MetaData
from instana_client.models.model_field import ModelField
from instana_client.models.parameter import Parameter
from typing import Optional, Set
from typing_extensions import Self

class Action(BaseModel):
    """
    Automation action definition. When this is used in policy creation request, only `id` should be specified.
    """ # noqa: E501
    created_at: datetime = Field(description="Action created time.", alias="createdAt")
    description: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=512)]] = Field(default=None, description="Action description.")
    fields: Optional[List[ModelField]] = Field(default=None, description="List of fields that describe an action.")
    id: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="Action identifier.")
    input_parameters: Optional[List[Parameter]] = Field(default=None, description="List of inputs to the action.", alias="inputParameters")
    metadata: Optional[MetaData] = None
    modified_at: datetime = Field(description="Action modified time.", alias="modifiedAt")
    name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="Action name.")
    tags: Optional[List[StrictStr]] = Field(default=None, description="List of tags added to the action.")
    type: Annotated[str, Field(min_length=0, strict=True, max_length=128)] = Field(description="Action type can be one of the following values:  SCRIPT, HTTP, ANSIBLE, EXTERNAL, GITHUB, GITLAB, JIRA, MANUAL, DOC_LINK")
    __properties: ClassVar[List[str]] = ["createdAt", "description", "fields", "id", "inputParameters", "metadata", "modifiedAt", "name", "tags", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['SCRIPT', 'HTTP', 'ANSIBLE', 'EXTERNAL', 'GITHUB', 'GITLAB', 'JIRA', 'MANUAL', 'DOC_LINK']):
            raise ValueError("must be one of enum values ('SCRIPT', 'HTTP', 'ANSIBLE', 'EXTERNAL', 'GITHUB', 'GITLAB', 'JIRA', 'MANUAL', 'DOC_LINK')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Action from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in fields (list)
        _items = []
        if self.fields:
            for _item_fields in self.fields:
                if _item_fields:
                    _items.append(_item_fields.to_dict())
            _dict['fields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in input_parameters (list)
        _items = []
        if self.input_parameters:
            for _item_input_parameters in self.input_parameters:
                if _item_input_parameters:
                    _items.append(_item_input_parameters.to_dict())
            _dict['inputParameters'] = _items
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Action from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdAt": obj.get("createdAt"),
            "description": obj.get("description"),
            "fields": [ModelField.from_dict(_item) for _item in obj["fields"]] if obj.get("fields") is not None else None,
            "id": obj.get("id"),
            "inputParameters": [Parameter.from_dict(_item) for _item in obj["inputParameters"]] if obj.get("inputParameters") is not None else None,
            "metadata": MetaData.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "modifiedAt": obj.get("modifiedAt"),
            "name": obj.get("name"),
            "tags": obj.get("tags"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.event import Event

class TestEvent(unittest.TestCase):
    """Event unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Event:
        """Test Event
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Event`
        """
        model = Event()
        if include_optional:
            return Event(
                end = 1,
                endpoint_service_id = '',
                entity_id = '',
                entity_type = 'Entity10',
                event_configuration_type = '',
                id = '',
                long_form_plugin_id = '',
                metadata = {
                    'key' : None
                    },
                metric_access_id = '',
                plugin = '',
                problem = instana_client.models.problem.Problem(
                    fix_suggestion = '', 
                    id = '', 
                    problem_text = '', 
                    severity = 56, ),
                rca = {
                    'key' : None
                    },
                start = 1,
                state = '',
                type = ''
            )
        else:
            return Event(
                entity_id = '',
                id = '',
                plugin = '',
                state = '',
                type = '',
        )
        """

    def testEvent(self):
        """Test Event"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_website_metrics import GetWebsiteMetrics

class TestGetWebsiteMetrics(unittest.TestCase):
    """GetWebsiteMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWebsiteMetrics:
        """Test GetWebsiteMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWebsiteMetrics`
        """
        model = GetWebsiteMetrics()
        if include_optional:
            return GetWebsiteMetrics(
                metrics = [
                    instana_client.models.website_monitoring_metrics_configuration.WebsiteMonitoringMetricsConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
                tag_filters = [
                    instana_client.models.deprecated_tag_filter.DeprecatedTagFilter(
                        entity = 'NOT_APPLICABLE', 
                        name = '', 
                        operator = 'EQUALS', 
                        value = '', )
                    ],
                time_frame = instana_client.models.time_frame.TimeFrame(
                    to = 56, 
                    window_size = 0, ),
                type = 'PAGELOAD'
            )
        else:
            return GetWebsiteMetrics(
                metrics = [
                    instana_client.models.website_monitoring_metrics_configuration.WebsiteMonitoringMetricsConfiguration(
                        aggregation = 'SUM', 
                        granularity = 56, 
                        metric = '', )
                    ],
                type = 'PAGELOAD',
        )
        """

    def testGetWebsiteMetrics(self):
        """Test GetWebsiteMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.custom_entity_with_metadata import CustomEntityWithMetadata

class TestCustomEntityWithMetadata(unittest.TestCase):
    """CustomEntityWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomEntityWithMetadata:
        """Test CustomEntityWithMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomEntityWithMetadata`
        """
        model = CustomEntityWithMetadata()
        if include_optional:
            return CustomEntityWithMetadata(
                created = 56,
                data = instana_client.models.custom_entity_model.CustomEntityModel(
                    dashboards = [
                        instana_client.models.custom_dashboard.CustomDashboard(
                            access_rules = [
                                instana_client.models.access_rule.AccessRule(
                                    access_type = 'READ', 
                                    related_id = '', 
                                    relation_type = 'USER', )
                                ], 
                            id = '', 
                            title = '', 
                            widgets = [
                                instana_client.models.widget.Widget(
                                    config = instana_client.models.config.config(), 
                                    height = 1, 
                                    id = '', 
                                    title = '', 
                                    type = '', 
                                    width = 1, 
                                    x = 0, 
                                    y = 0, )
                                ], )
                        ], 
                    dependencies = [
                        instana_client.models.custom_dependency.CustomDependency(
                            direction = 'outgoing', 
                            entity_type = '', 
                            identifiers = [
                                ''
                                ], 
                            name = '', 
                            type = 'in', )
                        ], 
                    identifiers = [
                        ''
                        ], 
                    label = '', 
                    metrics = [
                        instana_client.models.custom_metric.CustomMetric(
                            aggregation = 'AVG', 
                            category = '', 
                            description = '', 
                            formatter = 'NUMBER', 
                            label = '', 
                            name = '', 
                            section = 'ACE', 
                            source = '', 
                            type = '', )
                        ], 
                    tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                        type = '', ), ),
                id = '',
                version = ''
            )
        else:
            return CustomEntityWithMetadata(
                data = instana_client.models.custom_entity_model.CustomEntityModel(
                    dashboards = [
                        instana_client.models.custom_dashboard.CustomDashboard(
                            access_rules = [
                                instana_client.models.access_rule.AccessRule(
                                    access_type = 'READ', 
                                    related_id = '', 
                                    relation_type = 'USER', )
                                ], 
                            id = '', 
                            title = '', 
                            widgets = [
                                instana_client.models.widget.Widget(
                                    config = instana_client.models.config.config(), 
                                    height = 1, 
                                    id = '', 
                                    title = '', 
                                    type = '', 
                                    width = 1, 
                                    x = 0, 
                                    y = 0, )
                                ], )
                        ], 
                    dependencies = [
                        instana_client.models.custom_dependency.CustomDependency(
                            direction = 'outgoing', 
                            entity_type = '', 
                            identifiers = [
                                ''
                                ], 
                            name = '', 
                            type = 'in', )
                        ], 
                    identifiers = [
                        ''
                        ], 
                    label = '', 
                    metrics = [
                        instana_client.models.custom_metric.CustomMetric(
                            aggregation = 'AVG', 
                            category = '', 
                            description = '', 
                            formatter = 'NUMBER', 
                            label = '', 
                            name = '', 
                            section = 'ACE', 
                            source = '', 
                            type = '', )
                        ], 
                    tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                        type = '', ), ),
                id = '',
        )
        """

    def testCustomEntityWithMetadata(self):
        """Test CustomEntityWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CustomMetric(BaseModel):
    """
    CustomMetric
    """ # noqa: E501
    aggregation: Optional[StrictStr] = Field(default=None, description="Aggregation to apply on the metric for every member.")
    category: Optional[StrictStr] = Field(default=None, description="Category of the metric in the catalog")
    description: Optional[StrictStr] = Field(default=None, description="Description to be used in the catalog")
    formatter: Optional[StrictStr] = Field(default=None, description="| * NUMBER: Generic number * BYTES: Number of bytes * KILO_BYTES: Number of kilobytes * MEGA_BYTES: Number of megabytes * PERCENTAGE: Percentage in scale [0,1] * PERCENTAGE_100: Percentage in scale [0,100] * PERCENTAGE_NO_CAPPING: Percentage in scale [0,1] but value could exceed 1 for example when metric is aggregated * PERCENTAGE_100_NO_CAPPING: Percentage in scale [0,100] but value could exceed 100 for example when metric is aggregated * LATENCY: Time in milliseconds, with value of 0 should not be considered a a strict 0, but considered as < 1ms * NANOS: Time in nanoseconds * MILLIS: Time in milliseconds * MICROS: Time in microseconds * SECONDS: Time in seconds * RATE: Number of occurrences per second * BYTE_RATE: Number of bytes per second * UNDEFINED: Metric value unit is not known ")
    label: Optional[StrictStr] = Field(default=None, description="Label to be used in the catalog")
    name: Optional[StrictStr] = Field(default=None, description="Name of the metric")
    section: Optional[StrictStr] = Field(default=None, description="Section of the metric in the catalog")
    source: Optional[StrictStr] = Field(default=None, description="Name of the source metric")
    type: Optional[StrictStr] = Field(default=None, description="Type of entity for the source metric")
    __properties: ClassVar[List[str]] = ["aggregation", "category", "description", "formatter", "label", "name", "section", "source", "type"]

    @field_validator('aggregation')
    def aggregation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['AVG', 'SUM']):
            raise ValueError("must be one of enum values ('AVG', 'SUM')")
        return value

    @field_validator('formatter')
    def formatter_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['NUMBER', 'BYTES', 'KILO_BYTES', 'MEGA_BYTES', 'PERCENTAGE', 'PERCENTAGE_100', 'PERCENTAGE_NO_CAPPING', 'PERCENTAGE_100_NO_CAPPING', 'LATENCY', 'NANOS', 'MILLIS', 'MICROS', 'SECONDS', 'RATE', 'BYTE_RATE', 'UNDEFINED']):
            raise ValueError("must be one of enum values ('NUMBER', 'BYTES', 'KILO_BYTES', 'MEGA_BYTES', 'PERCENTAGE', 'PERCENTAGE_100', 'PERCENTAGE_NO_CAPPING', 'PERCENTAGE_100_NO_CAPPING', 'LATENCY', 'NANOS', 'MILLIS', 'MICROS', 'SECONDS', 'RATE', 'BYTE_RATE', 'UNDEFINED')")
        return value

    @field_validator('section')
    def section_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ACE', 'ALICLOUD', 'AWS', 'AZURE', 'CASSANDRA', 'CLOUD_FOUNDRY', 'CLR', 'COCKROACH', 'CONSUL', 'CONTAINER', 'COUCHBASE', 'DFQ', 'ELASTICSEARCH', 'GCP', 'HADOOP_YARN', 'HAZELCAST', 'IBM_CLOUD', 'IBM_DATAPOWER', 'IBM_I_SERIES', 'IBM_MQ', 'IBM_MQMFT', 'IBM_OPENSTACK', 'KAFKA_CONNECT', 'KUBERNETES', 'MONGO_DB', 'OTHERS', 'REDIS', 'SAP', 'SELF_MONITORING', 'SOLR', 'SPARK', 'TIBCOBW', 'TUXEDO', 'VSHPERE', 'WEBSPHERE', 'CUSTOM_ENTITY']):
            raise ValueError("must be one of enum values ('ACE', 'ALICLOUD', 'AWS', 'AZURE', 'CASSANDRA', 'CLOUD_FOUNDRY', 'CLR', 'COCKROACH', 'CONSUL', 'CONTAINER', 'COUCHBASE', 'DFQ', 'ELASTICSEARCH', 'GCP', 'HADOOP_YARN', 'HAZELCAST', 'IBM_CLOUD', 'IBM_DATAPOWER', 'IBM_I_SERIES', 'IBM_MQ', 'IBM_MQMFT', 'IBM_OPENSTACK', 'KAFKA_CONNECT', 'KUBERNETES', 'MONGO_DB', 'OTHERS', 'REDIS', 'SAP', 'SELF_MONITORING', 'SOLR', 'SPARK', 'TIBCOBW', 'TUXEDO', 'VSHPERE', 'WEBSPHERE', 'CUSTOM_ENTITY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomMetric from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomMetric from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aggregation": obj.get("aggregation"),
            "category": obj.get("category"),
            "description": obj.get("description"),
            "formatter": obj.get("formatter"),
            "label": obj.get("label"),
            "name": obj.get("name"),
            "section": obj.get("section"),
            "source": obj.get("source"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.cursor_paginated_business_activity_item import CursorPaginatedBusinessActivityItem

class TestCursorPaginatedBusinessActivityItem(unittest.TestCase):
    """CursorPaginatedBusinessActivityItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CursorPaginatedBusinessActivityItem:
        """Test CursorPaginatedBusinessActivityItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CursorPaginatedBusinessActivityItem`
        """
        model = CursorPaginatedBusinessActivityItem()
        if include_optional:
            return CursorPaginatedBusinessActivityItem(
                business_activity = instana_client.models.business_activity.BusinessActivity(
                    activity_id = 'ApproveInvoiceTask', 
                    activity_name = 'Approve Invoice', 
                    activity_start = 1680559706000, 
                    activity_type = 'userTask', 
                    call_id = '', 
                    endpoint_ids = [
                        ''
                        ], 
                    process_definition_id = 'invoice:2:aa2bbbcc-bb04-11ee-9d4e-0242ac110002', 
                    process_definition_name = 'Invoice Approval', 
                    root_process_instance_id = '486cbb3b-e633-11ee-8707-0242ac110002', ),
                cursor = instana_client.models.cursor.cursor(),
                metrics = {
                    'key' : [
                        [
                            1.337
                            ]
                        ]
                    }
            )
        else:
            return CursorPaginatedBusinessActivityItem(
                cursor = instana_client.models.cursor.cursor(),
        )
        """

    def testCursorPaginatedBusinessActivityItem(self):
        """Test CursorPaginatedBusinessActivityItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
